# frozen_string_literal: true

module Testimonium
  # CLI module
  module CLI
    require 'testimonium/cli/create'
    require 'testimonium/cli/helpers'
    require 'testimonium/cli/run'

    # The CLI is a class, entry point for CLI commands
    class CLI
      include Testimonium::CLI::Create
      include Testimonium::CLI::Helpers
      include Testimonium::CLI::Run

      def initialize(arguments)
        @arguments = arguments.dup
      end

      def evaluate
        parse_arguments!
      end

      def parse_arguments!
        argument = @arguments.shift

        begin
          case argument
          when 'create'
            parse_create_arguments!
          when 'run'
            parse_run_arguments!
          when 'version'
            puts Testimonium::VERSION
          when 'help'
            print_usage
          when nil
            print_usage
          else
            raise("Invalid command #{argument}.\nFor help use 'testimonium help'")
          end
        rescue StandardError => e
          puts e.message.to_s
          exit 1
        end
      end
    end
  end
end
