# frozen_string_literal: true

require 'logger'

def find_function(function_type, parameter, timeout_time = 2, retries = 5)
  element = nil
  count = 0

  retries.times do
    sleep timeout_time
    count += 1

    begin
      element = id(parameter) if function_type.eql?('id')
      element = text(parameter) if function_type.eql?('text')
    rescue Selenium::WebDriver::Error::NoSuchElementError
    end

    logger("Found: '#{parameter}' on attempt #{count}") if element
    return element if element
  end

  logger("Failed to find: '#{function_type} = #{parameter}'. Number of attempts: #{count}")
  false
end

def find_text_ios(parameter, timeout = 2, retries = 5)
  find_function('text', parameter, timeout, retries)
end

def find_element_id(parameter, timeout = 2, retries = 5)
  find_function('id', parameter, timeout, retries)
end

def device_android
  ENV['PLATFORM'] == 'android'
end

def device_ios
  ENV['PLATFORM'] == 'ios'
end

# @param msg [String] the log message
# @param severity [String] the severity of the message, 'debug' by default
def logger(msg, severity = 'debug')
  logger = Logger.new($stdout)
  logger.formatter = proc { |severity, datetime, _progname, msg| "#{severity}, #{datetime}, #{msg}\n" }

  if severity.eql?('debug')
    logger.debug(msg)
  elsif severity.eql?('fatal')
    logger.fatal(msg)
  else
    logger.info(msg)
  end
end
