# frozen_string_literal: true

module Testimonium
  # Tap functions
  module Tap
    # Tap element by id.
    #
    # @param id [String] Element ID.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def tap_element_by_id(id, timeout = 2, retries = 5)
      find_element_by_id(id, timeout, retries).click
    end

    # Tap element by text.
    #
    # @param text [String] Element Text.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def tap_element_by_text(text, timeout = 2, retries = 5)
      find_element_by_text(text, timeout, retries).click if device_android
      find_text_ios(text, timeout, retries).click if device_ios
    end

    # Tap element by xpath.
    #
    # @param xpath [String] Element Xpath.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def tap_element_by_xpath(path, timeout = 2, retries = 5)
      find_element_by_xpath(path, timeout, retries).click
    end

    # Tap element by resourceid.
    #
    # Android only: Needs app package name set as constant ANDROID_PACKAGE.
    #
    # @param id [String] Element ID.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def tap_element_by_resourceid(id, timeout = 2, retries = 5)
      if defined?(ANDROID_PACKAGE).nil?
        logger('ANDROID_PACKAGE is missing.', 'fatal')
        raise Selenium::WebDriver::Error::NoSuchElementError
      end

      find_element_by_resourceid(id, timeout, retries).click
    end
  end
end
