# frozen_string_literal: true

module Testimonium
  # Validate functions
  module Validate
    # Validate element by element id.
    #
    # @param id [String] Element ID.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def validate_element_by_id(id, timeout = 2, retries = 5)
      raise Selenium::WebDriver::Error::NoSuchElementError unless find_element_by_id(id, timeout, retries)
    end

    # Validate element by text.
    #
    # @param text [String] Element Text.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def validate_element_by_text(text, timeout = 5, retries = 5)
      raise Selenium::WebDriver::Error::NoSuchElementError unless find_element_by_text(text, timeout, retries)
    end

    # Validate element by xpath.
    #
    # @param xpath [String] Element Xpath.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def validate_element_by_xpath(path, timeout = 2, retries = 5)
      raise Selenium::WebDriver::Error::NoSuchElementError unless find_element_by_xpath(path, timeout, retries)
    end

    # Validate element by resourceid.
    #
    # Android only: Needs app package name set as constant ANDROID_PACKAGE.
    #
    # @param id [String] Element ID.
    # @param timeout [Integer] Timeout seconds between retries.
    # @param retries [Integer] Amount of retries.
    def validate_element_by_resourceid(id, timeout = 2, retries = 5)
      raise Selenium::WebDriver::Error::NoSuchElementError unless find_element_by_resourceid(id, timeout, retries)
    end
  end
end
